@@ -10,10 +10,10 @@ def init_wandb(cfg):
     """
 
     if not cfg.with_wandb:
-        log.debug('Weights and Biases integration disabled')
+        log.debug("Weights and Biases integration disabled")
         return
 
-    if 'wandb_unique_id' not in cfg:
+    if "wandb_unique_id" not in cfg:
         # if we're going to restart the experiment, this will be saved to a json file
         cfg.wandb_unique_id = f'{cfg.experiment}_{datetime.now().strftime("%Y%m%d_%H%M%S_%f")}'
 
@@ -21,8 +21,11 @@ def init_wandb(cfg):
     wandb_group = cfg.env if cfg.wandb_group is None else cfg.wandb_group
 
     log.debug(
-        'Weights and Biases integration enabled. Project: %s, user: %s, group: %s, unique_id: %s',
-        cfg.wandb_project, cfg.wandb_user, cfg.wandb_group, wandb_unique_id,
+        "Weights and Biases integration enabled. Project: %s, user: %s, group: %s, unique_id: %s",
+        cfg.wandb_project,
+        cfg.wandb_user,
+        cfg.wandb_group,
+        wandb_unique_id,
     )
 
     import wandb
@@ -31,19 +34,24 @@ def init_wandb(cfg):
     @retry(3, exceptions=(Exception,))
     def init_wandb_func():
         wandb.init(
-            project=cfg.wandb_project, entity=cfg.wandb_user, sync_tensorboard=True,
+            project=cfg.wandb_project,
+            entity=cfg.wandb_user,
+            sync_tensorboard=True,
             id=wandb_unique_id,
             name=wandb_unique_id,
-            group=wandb_group, job_type=cfg.wandb_job_type, tags=cfg.wandb_tags,
-            resume=True,
-            settings=wandb.Settings(start_method='fork'),
+            group=wandb_group,
+            job_type=cfg.wandb_job_type,
+            tags=cfg.wandb_tags,
+            resume="allow",
+            settings=wandb.Settings(start_method="fork"),
         )
 
-    log.debug('Initializing WandB...')
+    log.debug("Initializing WandB...")
     try:
         init_wandb_func()
     except Exception as exc:
-        log.error(f'Could not initialize WandB! {exc}')
+        log.error(f"Could not initialize WandB! {exc}")
+        raise
 
     wandb.config.update(cfg, allow_val_change=True)
 
@@ -51,4 +59,5 @@ def init_wandb(cfg):
 def finish_wandb(cfg):
     if cfg.with_wandb:
         import wandb
+
         wandb.run.finish()
